@@ -102,6 +102,8 @@ PLNfit <- R6Class(
           private$Sigma <- diag(sum(residuals^2)/(n*p), p, p)
         } else  if (control$covariance == "diagonal") {
           private$Sigma <- diag(diag(crossprod(residuals)/n), p, p)
+        } else  if (control$covariance == "heritability") {
+
         } else  {
           private$Sigma <- crossprod(residuals)/n + diag(colMeans(private$S2), nrow = p)
         }
@@ -114,24 +116,22 @@ PLNfit <- R6Class(
     optimize = function(responses, covariates, offsets, weights, control) {
 
       optimizer  <-
-        switch(control$covariance,
+        switch(self$vcov_model,
                "spherical" = cpp_optimize_spherical,
                "diagonal"  = cpp_optimize_diagonal ,
+               "genetic"   = cpp_optimize_genetic_modeling,
                "full"      = cpp_optimize_full
         )
 
-      optim_out <- optimizer(
-        list(
-          Theta = private$Theta,
-          M = private$M,
-          S = sqrt(private$S2)
-        ),
-        responses,
-        covariates,
-        offsets,
-        weights,
-        control
-      )
+      args <- list(Y = responses, X = covariates, O = offsets, w = weights, configuration = control)
+      if (self$vcov_model == "genetic") {
+        args$init_parameters <- list(Theta = private$Theta, M = private$M, S = sqrt(private$S2), rho = 0.25)
+        args$C <- control$corr_matrix
+      } else {
+        args$init_parameters <- list(Theta = private$Theta, M = private$M, S = sqrt(private$S2))
+      }
+
+      optim_out <- do.call(optimizer, args)
 
       Ji <- optim_out$loglik
       attr(Ji, "weights") <- weights
@@ -145,20 +145,27 @@ PLNfit <- R6Class(
         Ji         = Ji,
         monitoring = list(
           iterations = optim_out$iterations,
-          status     = optim_out$status,
           message    = statusToMessage(optim_out$status))
       )
+
+      if (self$vcov_model == "genetic")
+        private$psi <- list(sigma2 = optim_out$sigma2, rho = optim_out$rho)
     },
 
     #' @description Result of one call to the VE step of the optimization procedure: optimal variational parameters (M, S) and corresponding log likelihood values for fixed model parameters (Sigma, Theta). Intended to position new data in the latent space.
+    #' @param Theta Optional fixed value of the regression parameters
+    #' @param Sigma Optional fixed value of the covariance parameters.
     #' @return A list with three components:
     #'  * the matrix `M` of variational means,
     #'  * the matrix `S2` of variational variances
     #'  * the vector `log.lik` of (variational) log-likelihood of each new observation
-    VEstep = function(covariates, offsets, responses, weights, control = list()) {
+    VEstep = function(covariates, offsets, responses, weights,
+                      Theta = self$model_par$Theta,
+                      Sigma = self$model_par$Sigma,
+                      control = list()) {
 
       # problem dimension
-      n <- nrow(responses); p <- ncol(responses); d <- ncol(covariates)
+      n <- nrow(responses); p <- ncol(responses)
 
       ## define default control parameters for optim and overwrite by user defined parameters
       control$covariance <- self$vcov_model
@@ -168,7 +175,8 @@ PLNfit <- R6Class(
         switch(control$covariance,
                "spherical" = cpp_optimize_vestep_spherical,
                "diagonal"  = cpp_optimize_vestep_diagonal,
-               "full"      = cpp_optimize_vestep_full
+               "full"      = cpp_optimize_vestep_full,
+               "genetic"   = cpp_optimize_vestep_full
         )
 
       ## Initialize the variational parameters with the appropriate new dimension of the data
@@ -178,9 +186,9 @@ PLNfit <- R6Class(
         covariates,
         offsets,
         weights,
-        Theta = self$model_par$Theta,
+        Theta = Theta,
         ## Robust inversion using Matrix::solve instead of solve.default
-        Omega = as(Matrix::solve(Matrix::Matrix(self$model_par$Sigma)), 'matrix'),
+        Omega = as(Matrix::solve(Matrix::Matrix(Sigma)), 'matrix'),
         control
       )
 
@@ -285,7 +293,7 @@ PLNfit <- R6Class(
     #' @param envir Environment in which the prediction is evaluated
     #' @return A matrix with predictions scores or counts.
     predict = function(newdata, type = c("link", "response"), envir = parent.frame()) {
-      type = match.arg(type)
+      type <- match.arg(type)
 
       ## Extract the model matrices from the new data set with initial formula
       X <- model.matrix(formula(private$formula)[-2], newdata, xlev = private$xlevels)
@@ -303,6 +311,76 @@ PLNfit <- R6Class(
       results
     },
 
+    #' @description Predict position, scores or observations of new data, conditionally on the observation of a (set of) variables
+    #' @param cond_responses a data frame containing the count of the observed variables (matching the names of the provided as data in the PLN function)
+    #' @param newdata a data frame containing the covariates of the sites where to predict
+    #' @param type Scale used for the prediction. Either `link` (default, predicted positions in the latent space) or `response` (predicted counts).
+    #' @param var_par Boolean. Should new estimations of the variational parameters of mean and variance be sent back, as attributes of the matrix of predictions. Default to \code{FALSE}.
+    #' @param envir Environment in which the prediction is evaluated
+    #' @return A matrix with predictions scores or counts.
+    predict_cond = function(newdata, cond_responses, type = c("link", "response"), var_par = FALSE, envir = parent.frame()){
+      type <- match.arg(type)
+
+      # Checks
+      Yc <- as.matrix(cond_responses)
+      sp_names <- rownames(self$model_par$Theta)
+      if (! any(colnames(cond_responses) %in% sp_names))
+        stop("Yc must be a subset of the species in responses")
+      if (! nrow(Yc) == nrow(newdata))
+        stop("The number of rows of Yc must match the number of rows in newdata")
+
+      # Dimensions and subsets
+      n_new <- nrow(Yc)
+      cond <- sp_names %in% colnames(Yc)
+
+      ## Extract the model matrices from the new data set with initial formula
+      X <- model.matrix(formula(private$formula)[-2], newdata, xlev = private$xlevels)
+      O <- model.offset(model.frame(formula(private$formula)[-2], newdata))
+      if (is.null(O)) O <- matrix(0, n_new, self$p)
+
+      # Compute parameters of the law
+      vcov11 <- private$Sigma[cond ,  cond, drop = FALSE]
+      vcov22 <- private$Sigma[!cond, !cond, drop = FALSE]
+      vcov12 <- private$Sigma[cond , !cond, drop = FALSE]
+      A <- crossprod(vcov12, solve(vcov11))
+      Sigma21 <- vcov22 - A %*% vcov12
+
+      # Call to VEstep to obtain M1, S1
+      VE <- self$VEstep(
+              covariates = X,
+              offsets    = O[, cond, drop = FALSE],
+              responses  = Yc,
+              weights    = rep(1, n_new),
+              Theta      = self$model_par$Theta[cond, , drop = FALSE],
+              Sigma      = vcov11
+          )
+
+      M <- tcrossprod(VE$M, A)
+      S <- map(1:n_new, ~crossprod(sqrt(VE$S2[., ]) * t(A)) + Sigma21) %>%
+        simplify2array()
+
+      ## mean latent positions in the parameter space
+      EZ <- tcrossprod(X, private$Theta[!cond, , drop = FALSE]) + M
+      EZ <- EZ + O[, !cond, drop = FALSE]
+      colnames(EZ) <- setdiff(sp_names, colnames(Yc))
+
+      # ! We should only add the .5*diag(S2) term only if we want the type="response"
+      if (type == "response"){
+        if(ncol(EZ)==1){
+          EZ <- EZ + .5 *S
+        }else{
+          EZ <- EZ + .5 * t(apply(S, 3, diag))
+        }
+      }
+      results <- switch(type, link = EZ, response = exp(EZ))
+      attr(results, "type") <- type
+      if (var_par) {
+        attr(results, "M") <- M
+        attr(results, "S") <- S
+      }
+      results
+    },
+
     ## %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
     ## Print functions -----------------------
     #' @description User friendly print method
@@ -316,7 +394,8 @@ PLNfit <- R6Class(
       cat("    $model_par, $latent, $latent_pos, $var_par, $optim_par\n")
       cat("    $loglik, $BIC, $ICL, $loglik_vec, $nb_param, $criteria\n")
       cat("* Useful S3 methods\n")
-      cat("    print(), coef(), sigma(), vcov(), fitted(), predict(), standard_error()\n")
+      cat("    print(), coef(), sigma(), vcov(), fitted()\n")
+      cat("    predict(), predict_cond(), standard_error()\n")
     },
 
     #' @description User friendly print method
@@ -340,6 +419,7 @@ PLNfit <- R6Class(
     A          = NA, # the matrix of expected counts
     R2         = NA, # approximated goodness of fit criterion
     Ji         = NA, # element-wise approximated loglikelihood
+    psi        = NA, # parameters for genetic model of covariance
     FIM        = NA, # Fisher information matrix of Theta, computed using of two approximation scheme
     FIM_type   = NA, # Either "wald" or "louis". Approximation scheme used to compute FIM
     .std_err   = NA, # element-wise standard error for the elements of Theta computed
@@ -367,6 +447,8 @@ PLNfit <- R6Class(
     std_err    = function() {private$.std_err },
     #' @field var_par a list with two matrices, M and S2, which are the estimated parameters in the variational approximation
     var_par    = function() {list(M = private$M, S2 = private$S2)},
+    #' @field gen_par a list with two parameters, sigma2 and rho, only used with the genetic covariance model
+    gen_par    = function() {private$psi},
     #' @field latent a matrix: values of the latent vector (Z in the model)
     latent     = function() {private$Z},
     #' @field latent_pos a matrix: values of the latent position vector (Z) without covariates effects or offset
@@ -375,7 +457,7 @@ PLNfit <- R6Class(
     fitted     = function() {private$A},
     #' @field nb_param number of parameters in the current PLN model
     nb_param   = function() {
-      res <- self$p * self$d + switch(private$covariance, "full" = self$p * (self$p + 1)/2, "diagonal" = self$p, "spherical" = 1)
+      res <- self$p * self$d + switch(private$covariance, "full" = self$p * (self$p + 1)/2, "diagonal" = self$p, "spherical" = 1, "genetic" = 2)
       as.integer(res)
     },
     #' @field vcov_model character: the model used for the covariance (either "spherical", "diagonal" or "full")
