@@ -26,7 +26,7 @@ test_that("PLNLDA fit: check classes, getters and field access",  {
 
   expect_true(inherits(model$group_means, "matrix"))
   expect_true(inherits(sigma(model), "matrix"))
-  expect_true(class(vcov(model)) == "dgCMatrix")
+  # expect_true(inherits(vcov(model), "dsCMatrix"))
 
   expect_equal(dim(vcov(model)), c(model$d * model$p, model$d * model$p))
 
@@ -73,7 +73,8 @@ capture_output(print(as.data.frame(round(model$criteria, digits = 3), row.names
     $model_par, $latent, $latent_pos, $var_par, $optim_par
     $loglik, $BIC, $ICL, $loglik_vec, $nb_param, $criteria
 * Useful S3 methods
-    print(), coef(), sigma(), vcov(), fitted(), predict(), standard_error()
+    print(), coef(), sigma(), vcov(), fitted()
+    predict(), predict_cond(), standard_error()
 * Additional fields for LDA
     $percent_var, $corr_map, $scores, $group_means
 * Additional S3 methods for LDA
@@ -151,26 +152,28 @@ test_that("Predictions are not affected by inclusion of an intercept.", {
                predict(model , newdata = trichoptera))
 })
 
-# test_that("Predictions work when train and test data have different factor levels.", {
-#   suppressWarnings(
-#     toy_data <- prepare_data(
-#       counts     = matrix(c(1, 4, 2, 1,
-#                             1, 8, 2, 1),
-#                           ncol = 2),
-#       covariates = data.frame(Cov   = c("A", "B", "B", "A"),
-#                               Group = c("a", "b", "a", "a")),
-#       offset     = matrix(rep(1, 8), ncol = 2)
-#   ))
-#   suppressWarnings(
-#     model <- PLNLDA(Abundance ~ Cov + offset(log(Offset)),
-#                     grouping = Group,
-#                     data     = toy_data[1:3,])
-#   )
-#   # expect_length(predict(model, newdata = toy_data[c(1,4), ], type = "r"),
-#   #               2L)
-#   # expect_identical(predict(model, newdata = toy_data[c(1,4), ], type = "r"),
-#   #                  factor(c(`1` = "a", `4` = "a"), levels = c("a", "b")))
-# })
+test_that("Predictions works when train and test data have different factor levels.", {
+  sample_names <- paste0("S", 1:4)
+  species_names <- paste0("Y", 1:2)
+  toy_data <- prepare_data(
+    counts     = matrix(c(1, 4, 2, 1,
+                          1, 8, 2, 1),
+                        ncol = 2,
+                        dimnames = list(sample_names, species_names)),
+    covariates = data.frame(Cov   = c("A", "B", "B", "A"),
+                            Group = c("a", "b", "a", "a"),
+                            row.names = sample_names),
+    offset     = matrix(rep(1, 8), ncol = 2,
+                        dimnames = list(sample_names, species_names))
+  )
+  model <- PLNLDA(Abundance ~ Cov + offset(log(Offset)),
+                    grouping = Group,
+                    data     = toy_data[1:4,])
+  expect_length(predict(model, newdata = toy_data[c(1,4), ], type = "r"),
+                2L)
+  expect_identical(predict(model, newdata = toy_data[c(1,4), ], type = "r"),
+                   factor(c(`S1` = "a", `S4` = "a"), levels = c("a", "b")))
+})
 
 
 test_that("Prediction fails for non positive prior probabilities.", {
